@@ -89,7 +89,7 @@ def classic_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	except:
 		print('No histograms')
 	return
-def quantum_analysis(suceptibility,binder,correlation,L,rho):
+def quantum_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	def compute_cumulants_gammas(q2,q4,sp):
 		q2_l=sort_and_build(q2,1)
 		q4_l=sort_and_build(q4,1)
@@ -158,6 +158,7 @@ def quantum_analysis(suceptibility,binder,correlation,L,rho):
 	#Printing FSS file
 	n_instances=np.shape(q)
 	number=np.shape(q2_avg)[0]
+	print(n_instances,number)
 	fcc=open('fss.dat','w')
 	fcc.write('# Number of instances :'+str(n_instances[0]/number)+'\n')
 	for j in cumulants:
@@ -168,8 +169,8 @@ def quantum_analysis(suceptibility,binder,correlation,L,rho):
 	try:
 		histogram_q=np.loadtxt('histogram_q.dat')
 		histogram_q_l=np.loadtxt('histogram_q_l.dat')
-		plot_histogram_q(histogram_q)
-		plot_histogram_q_l(histogram_q_l)
+		plot_histogram_q(histogram_q,arr_q)
+		plot_histogram_q_l(histogram_q_l,arr_ql)
 	except:
 		print('No histograms')
 	return
\ No newline at end of file
