@@ -94,15 +94,15 @@ def array_equilibrium(lista,name,plot_fig,x_label,y_label):
       plt.tick_params( which='minor',direction='in',bottom=True, top=True, left=True, right=True)
       plt.rc('font', family='serif')
       #plt.tight_layout()
-      plt.rcParams.update({'font.size': 17})
+      plt.rcParams.update({'font.size': 10})
       plt.rc('text', usetex=True)
-      plt.legend(title=r'$\Gamma$',frameon=False,loc='best',fontsize=12)
+      plt.legend(title=r'$\Gamma$',frameon=False,loc='best',fontsize=10)
       plt.tight_layout()
       plt.savefig('equilibrium_'+name+'.eps')
       plt.clf()
       plt.cla()
       # Plotting the results
-      plt.rcParams.update({'font.size': 17})
+      plt.rcParams.update({'font.size': 10})
       plt.rc('text', usetex=True)
       plt.tight_layout()
       plt.xlabel(x_label)
@@ -143,7 +143,7 @@ def plot_histogram_q(data,arr):
          clean1=data[np.where(data[:,0]==w)]
          plt.clf()
          plt.cla()
-         plt.rcParams.update({'font.size': 17})
+         plt.rcParams.update({'font.size': 10})
          plt.rc('text', usetex=True)
          plt.tight_layout()
          plt.ylabel(r'$P(q)$')
@@ -167,11 +167,11 @@ def plot_histogram_q(data,arr):
                 y_array.append(y_aver)
                 err_array.append(y_err)
             #Plotting the averaged histogram
-            plt.errorbar(x_array,y_array, yerr=err_array, fmt='+', label=str(g))
-         plt.legend(loc='center left')
+            if ((g in arr) or (len(arr)==0)):
+                plt.errorbar(x_array,y_array, yerr=err_array, fmt='+', label=str(g))
+         plt.legend(loc='upper left')
          plt.tight_layout()
-         if ((g in arr) or (len(arr)==0)):
-            plt.savefig('histogram_q_window'+str(w)+'.eps')
+         plt.savefig('histogram_q_window'+str(w)+'.eps')
          plt.clf()
          plt.cla()
      plt.close
@@ -185,7 +185,7 @@ def plot_histogram_q_l(data,arr):
          clean1=data[np.where(data[:,0]==w)]
          plt.clf()
          plt.cla()
-         plt.rcParams.update({'font.size': 17})
+         plt.rcParams.update({'font.size': 10})
          plt.rc('text', usetex=True)
          plt.tight_layout()
          plt.ylabel(r'$P(q)$')
@@ -209,14 +209,11 @@ def plot_histogram_q_l(data,arr):
                 y_array.append(y_aver)
                 err_array.append(y_err)
             #Plotting the averaged histogram
-            plt.errorbar(x_array,y_array, yerr=err_array, fmt='+', label=str(g))
-         plt.legend(loc='center left')
+            if ((g in arr) or (len(arr)==0)):
+                plt.errorbar(x_array,y_array, yerr=err_array, fmt='+', label=str(g))
+         plt.legend(loc='upper left')
          plt.tight_layout()
-         print((g in arr),g,arr)
-         print((len(arr)==0),len(arr))
-         print(((g in arr) or (len(arr)==0)))
-         if ((g in arr) or (len(arr)==0)):
-                plt.savefig('histogram_q_l_window'+str(w)+'.eps')
+         plt.savefig('histogram_q_l_window'+str(w)+'.eps')
          plt.clf()
          plt.cla()
      plt.close
